"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FileStorage = void 0;
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _error = _interopRequireDefault(require("@webiny/error"));
const storagePluginType = "api-file-manager-storage";
class FileStorage {
  constructor({
    context
  }) {
    (0, _defineProperty2.default)(this, "context", void 0);
    this.context = context;
  }
  get storagePlugin() {
    const storagePlugin = this.context.plugins.byType(storagePluginType).pop();
    if (!storagePlugin) {
      throw new _error.default(`Missing plugin of type "${storagePluginType}".`, "STORAGE_PLUGIN_ERROR");
    }
    return storagePlugin;
  }
  async upload(params) {
    const settings = await this.context.fileManager.getSettings();
    if (!settings) {
      throw new _error.default("Missing File Manager Settings.", "FILE_MANAGER_ERROR");
    }

    // Add file to cloud storage.
    const {
      file: fileData
    } = await this.storagePlugin.upload((0, _objectSpread2.default)((0, _objectSpread2.default)({}, params), {}, {
      settings
    }));

    // Save file in DB.
    return this.context.fileManager.createFile((0, _objectSpread2.default)((0, _objectSpread2.default)({}, fileData), {}, {
      meta: {
        private: Boolean(params.hideInFileManager)
      },
      tags: Array.isArray(params.tags) ? params.tags : []
    }));
  }
  async uploadFiles({
    files
  }) {
    const settings = await this.context.fileManager.getSettings();
    if (!settings) {
      throw new _error.default("Missing File Manager Settings.", "FILE_MANAGER_ERROR");
    }
    const filesData = await Promise.all(files.map(async item => {
      // TODO: improve types of this.storagePlugin.
      const {
        file
      } = await this.storagePlugin.upload((0, _objectSpread2.default)((0, _objectSpread2.default)({}, item), {}, {
        settings
      }));
      return (0, _objectSpread2.default)((0, _objectSpread2.default)({}, file), {}, {
        meta: {
          private: Boolean(item.hideInFileManager)
        },
        tags: Array.isArray(item.tags) ? item.tags : []
      });
    }));
    return this.context.fileManager.createFilesInBatch(filesData);
  }
  async delete(params) {
    const {
      id,
      key
    } = params;
    const {
      fileManager
    } = this.context;
    // Delete file from cloud storage.
    await this.storagePlugin.delete({
      key
    });

    // Delete file from the DB.
    return await fileManager.deleteFile(id);
  }
}
exports.FileStorage = FileStorage;